State of Maine Judicial Branch: Supreme Court Opinions

- Skip First Level Navigation
- Skip All Navigation

## Maine.gov

- Agencies |
- Online Services |
- Help |
- Search Maine.gov

Page Tools

## State of Maine Judicial Branch

# Published Opinions of the Law Court

These opinions are subject to motions for reconsideration pursuant to Rule 14(b) of the Maine Rules of Appellate Procedure, and to revision and correction before final publication. Readers are asked to notify the Reporter of Decisions of any typographical, grammatical or other formal errors by U.S. Mail to Clerk of the Law Court, 205 Newbury Street, Room 139, Portland, ME 04101-4125, or by filling out the form on the Contact Us page of this website.

The permanent, official versions of Maine Supreme Judicial Court's opinions are those published in the Atlantic Reporter (2d Series and 3d Series), which has been Maine's official reporter since 1966.

Opinions have been published online since January 1997. Decisions published online should be cited in the following style:

> Dutil v. Burns, 1997 ME 1,¶ 2, 687 A.2d 639.

##

## Citations

Maine Law Review: Uniform Maine Citations

Uniform Maine Citations, 2014 Edition, provides updated rules for the citation of Maine legal authorities, including judicial decisions, constitutional provisions, statutory and legislative materials, court rules, treatises, periodicals, and miscellaneous Maine authorities.

##

## Opinions

Opinions published online since January 2006 are in pdf format. The free Adobe Acrobat Reader is necessary to view those opinions.

## Previous years' opinions

2013 | 2009 | 2005 | 2001 | 1997
2012 | 2008 | 2004 | 2000 |
2011 | 2007 | 2003 | 1999 |
2010 | 2006 | 2002 | 1998 |

##

## This year's opinions

November 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 120 | Cynthia (Martin) Remick v. Kevin Martin | November 4, 2014
2014 ME 121 | Town of Madawaska v. Richard Cayer et al. | November 4, 2014
2014 ME 122 | Dubois Livestock Inc. v. Town of Arundel et al. | November 4, 2014
2014 ME 123 | Gina Turcotte v. Humane Society Waterville Area | November 4, 2014
2014 ME 124 | State of Maine v. Stephen Treadway | November 4, 2014
2014 ME 125 | Daniel P. Roberts v. State of Maine | November 6, 2014
2014 ME 126 | Paul Beaudry et al. v. Alan Harding et al. | November 13, 2014
2014 ME 127 | David G. Fleming v. Department of Corrections et al. | November 13, 2014
2014 ME 128 | In re M.C. | November 13, 2014

October 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 113 | U.S. Bank National Association as Trustee v. Charles Adams et al. | October 7, 2014
2014 ME 114 | Charles Remmel et al. v. City of Portland et al. | October 16, 2014
2014 ME 115 | Sarah Craig v. Krystal Gayle Caron | October 21, 2014
2014 ME 116 | Passadumkeag Mountain Friends et al. v. Board of Environmental Protection et al. | October 21, 2014
2014 ME 117 | Catherine Duffy Petit v. William Lumb | October 30, 2014
2014 ME 118 | Anthony J. Tuell v. Janice I. Nicholson | October 30, 2014
2014 ME 119 | Estate of Margaret C. Gray | October 30, 2014

September 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 110 | Patrick T. Jackson III v. Sally A. (Jackson) Macleod | September 9,2014
2014 ME 111 | Patrick A. Burrow v. Rachel L. Burrow | September 18, 2014
2014 ME 112 | Christine M. Starrett v. Irven G. Starrett | September 18, 2014

August 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 100 | Reva Merrill v. Maine Public Employees Retirement System | August 5, 2014
2014 ME 101 | Santina Caruso v. The Jackson Laboratory | August 7, 2014
2014 ME 102 | Francis Small Heritage Trust, Inc. v. Town of Limington et al | August 7, 2014
2014 ME 103 | Marjorie J. Getz et al v. Janis Walsh et al ***** David M. Torangeau et al v. Janis Walsh et al | August 7, 2014
2014 ME 104 | Guardianship of Gabriel I.K. Johnson | August 12, 2014
2014 ME 105 | Estate of Harold Forest Snow | August 14, 2014
2014 ME 106 | Michael J. Dee v. State of Maine | August 14, 2014
2014 ME 107 | Samsara Memorial Trust v. Kelly, Remmel & Zimmerman Kelly, Remmel & Zimmerman v. Raisin Memorial Trust et al. Corrected November 13, 2014 (Errata sheet) | August 19, 2014
2014 ME 108 | Timothy G. Dalton v. Sarah H. Dalton Corrected November 13, 2014 (Errata sheet) | August 19, 2014
2014 ME 109 | Richard S. Sullivan v. Jane Doe | August 28, 2014

July 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 87 | In re E.L., et al. | July 1, 2014
2014 ME 88 | Glen C. Harrington III v. State of Maine | July 1, 2014
2014 ME 89 | Bank of America, N.A. v. Scott A. Greenleaf et al. | July 3, 2014
2014 ME 90 | State of Maine v. Karl V. Kittredge | July 10, 2014
2014 ME 91 | Douglas H. Watts v. Board of Environmental Protection et al. | July 15, 2014
2014 ME 92 | State of Maine v. Chad A. Logan | July 15, 2014
2014 ME 93 | The Cote Corporation v. Kelley Earthworks, Inc., et al. | July 17, 2014
2014 ME 94 | State of Maine v. Luke A. Bryant | July 22, 2014
2014 ME 95 | In re L.R. | July 24, 2014
2014 ME 96 | U.S. Bank N.A. v. Thomas Manning et al. Corrected November 13, 2014 (Errata sheet) | July 24, 2014
2014 ME 97 | State of Maine v. Dwight A. Norwood | July 31, 2014
2014 ME 98 | In re M.E. | July 31, 2014
2014 ME 99 | In re B.C. | July 31, 2014

June 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 74 | State of Maine v. Julia Peck | June 10, 2014
2014 ME 75 | Estate of Ruth E. O'Brien-Hamel | June 10, 2014
2014 ME 76 | John A. Thurston et al. v. Jenny G. Galvin | June 10, 2014
2014 ME 77 | Wendell Strout Jr. v. Central Maine Medical Center | June 10, 2014
2014 ME 78 | Janet Howe et al. v. MMG Insurance Company | June 17, 2014
2014 ME 79 | State of Maine v. Dan Brown | June 17, 2014
2014 ME 80 | Guardianship of Riley J. Young | June 19, 2014
2014 ME 81 | U.S. Bank, N.A. v. David Sawyer et al. | June 24, 2014
2014 ME 82 | Nicholas Stein v. Maine Criminal Justice Academy | June 24, 2014
2014 ME 83 | State of Maine v. Erving M. Johnson | June 24, 2014
2014 ME 84 | Alayna J. Laprel et al. v. Douglas J. Going | June 24, 2014
2014 ME 85 | Pike Industries, Inc. v. City of Westbrook et al. | June 26,2014
2014 ME 86 | State of Maine v. Cleveland O. Cruthirds | June 26, 2014

May 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 62 | Irving Oil Limited et al. v. ACE INA Insurance | May 1, 2014
2014 ME 63 | Friends of Congress Square Park et al. v. City of Portland | May 6, 2014
2014 ME 64 | Paula Bratton et al. v. Halsey McDonough | May 6, 2014
2014 ME 65 | State of Maine v. David W. Troy | May 8, 2014
2014 ME 66 | The Bank of New York Mellon, N.A. v. Re/Max Realty One | May 8, 2014
2014 ME 67 | North Atlantic Securities, LLC, et al. v. Office of Securities | May 15, 2014
2014 ME 68 | State of Maine v. Thomas D. Johnson | May 20, 2014
2014 ME 69 | State of Maine v. Michael W. Chapman | May 22, 2014
2014 ME 70 | Glenn A. Griffin v. Cristie J. Griffin | May 22, 2014
2014 ME 71 | In re K.S. | May 29, 2014
2014 ME 72 | Christine S. Angell v. Renald C. Hallee | May 29, 2014
2014 ME 73 | Estate of Clarence Weatherbee Estate of Helen Weatherbee | May 29, 2014

April 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 51 | Philip C. Tobin v. Philip N. Barter | April 1, 2014
2014 ME 52 | Mallinckrodt US LLC et al. v. Department of Environmental Protection | April 3, 2014
2014 ME 53 | Robin S. Hutchinson v. Jennie E. (Hutchinson) Cobb | April 3, 2014
2014 ME 54 | In re M.S. | April 8, 2014
2014 ME 55 | State of Maine v. Charles R. Black | April 8, 2014
2014 ME 56 | Central Maine Power Company v. Public Utilities Commission | April 8, 2014
2014 ME 57 | Marc B. Terfloth v. Town of Scarborough | April 8, 2014
2014 ME 58 | F. Lee Bailey v. Board of Bar Examiners | April 10, 2014
2014 ME 59 | Matthew W. Pitts v. Amanda M. Moore | April 17, 2014
2014 ME 60 | Linda J. Clifford v. MaineGeneral Medical Center et al. | April 22, 2014
2014 ME 61 | James R. Eaton v. Kelly L. Paradis | April 29, 2014

March 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 34 | Estate of Michael Lewis v. Concord General Mutual Insurance Company | March 4, 2014
2014 ME 35 | State of Maine v. Andrew J. Freeman | March 4, 2014
2014 ME 36 | Adoption of T.D. | March 4, 2014
2014 ME 37 | Bayview Loan Servicing, LLC v. John H. Bartlett et al. | March 4, 2014
2014 ME 38 | Houlton Water Company et al. v. Public Utilities Commission | March 4, 2014
2014 ME 39 | Patricia A. McCollor v. Frederick J. McCollor Jr. et al. | March 4, 2014
2014 ME 40 | Estate of Robert L. Collopy | March 6, 2014
2014 ME 41 | Edwina Jones v. Cost Management, Inc. | March 6, 2014
2014 ME 42 | Clifford Lippitt v. Board of Certification for Geologists and Soil Scientists | March 11, 2014
2014 ME 43 | State of Maine v. Reginald Dube | March 18, 2014
2014 ME 44 | Sharon Cassidy v. City of Bangor et al. | March 18, 2014
2014 ME 45 | State of Maine v. Arnold A. Diana | March 20, 2014
2014 ME 46 | John S. Zablotny v. State Board of Nursing | March 20, 2014
2014 ME 47 | State of Maine v. Elfido Marroquin-Aldana | March 25, 2014
2014 ME 48 | State of Maine v. Jason M. Lovejoy | March 27, 2014
2014 ME 49 | State of Maine v. Spencer T. Glover | March 27, 2014
2014 ME 50 | State of Maine v. Samuel Sanchez | March 27, 2014

February 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 12 | Robert F. Almeder et al. v. Town of Kennebunkport et al. | February 4, 2014
2014 ME 13 | Christine A. Murphy v. William E. Bartlett | February 4, 2014
2014 ME 14 | State of Maine v. Lisha Rose Stanley | February 4, 2014
2014 ME 15 | In re M.M. | February 11, 2014
2014 ME 16 | State of Maine v. Seth J. Hill | February 11, 2014
2014 ME 17 | Lewis Lubar, Trustee of the Clover Trust v. Frederick W. Connelly | February 11, 2014
2014 ME 18 | Ellen J. Clark v. John Brian McLane | February 11, 2014
2014 ME 19 | Estate of Daniel Nickerson v. Alan Carter et al. | February 11, 2014
2014 ME 20 | Bangor Savings Bank v. Robin N. Richard | February 11, 2014
2014 ME 21 | Stephen W. Riffle et al. v. S. David Smith et al. | February 11, 2014
2014 ME 22 | Estate of Vera Boulier v. Presque Isle Nursing Home | February 13, 2014
2014 ME 23 | State of Maine v. Nicholas A. Gladu | February 18, 2014
2014 ME 24 | Jeffrey A. Cookson v. State of Maine | February 18, 2014
2014 ME 25 | Guardianship of Zacharia Hartley Stevens | February 18, 2014
2014 ME 26 | Kennebec County v. Maine Public Employees Retirement System | February 20, 2014
2014 ME 27 | Richard C. Hickson v. Vescom Corporation | February 25, 2014
2014 ME 28 | State of Maine v. Jay S. Mercier | February 25, 2014
2014 ME 29 | State of Maine v. Aaron S. Lowden | February 25, 2014
2014 ME 30 | In re G.W. | February 25, 2014
2014 ME 31 | State of Maine v. Joel A. Hayden | February 25, 2014
2014 ME 32 | Estate of Ada Y. Greenblatt | February 25, 2014
2014 ME 33 | William Clark v. Hancock County Commissioners | February 27, 2014

January 2014
Opinion # | Case | Date
--- | --- | ---
2014 ME 1 | In re Steven L. | January 9, 2014
2014 ME 2 | Estate of Mary E. Hiller | January 9, 2014
2014 ME 3 | Lisa Lesko v. Theodore Stanislaw | January 14, 2014
2014 ME 4 | John McClare v. James J. Rocha | January 14, 2014
2014 ME 5 | Jessica A. (Nadeau) Potila v. Larry A. Nadeau | January 16, 2014
2014 ME 6 | Preti Flaherty Beliveau & Pachios LLP v. State Tax Assessor | January 16, 2014
2014 ME 7 | Ford Motor Company v. Darling's et al. | January 21, 2014
2014 ME 8 | Nicole Dussault v. RRE Coach Lantern Holdings, LLC, et al. | January 23, 2014
2014 ME 9 | State of Maine v. David W. Troy | January 23, 2014
2014 ME 10 | Estate of Gloria P. Hall | January 28, 2014
2014 ME 11 | John Doe et al. v. Regional School Unit 26 | January 30, 2014